pub struct Connection { /* private fields */ }Implementations
Sourceimpl Connection
impl Connection
Sourcepub async fn connect(
reg: &Registration,
config: &Configuration,
server_name: &str,
server_port: u16,
) -> Result<Self, Status>
pub async fn connect( reg: &Registration, config: &Configuration, server_name: &str, server_port: u16, ) -> Result<Self, Status>
Connects to the server Note: Registration must be kept outside of connection and must wait for all connections to finish before closing, else registration close will wait on system lock, and block rust runtime.
Sourcepub fn get_shutdown_waiter(&mut self) -> ConnectionShutdownWaiter
pub fn get_shutdown_waiter(&mut self) -> ConnectionShutdownWaiter
Can only be called once after construction.